@@ -9,7 +9,7 @@ Michael Hucka <mhucka@caltech.edu> -- Caltech Library
 Copyright
 ---------
 
-Copyright (c) 2018-2021 by the California Institute of Technology.  This code
+Copyright (c) 2018-2022 by the California Institute of Technology.  This code
 is open-source software released under a 3-clause BSD license.  Please see the
 file "LICENSE" for more information.
 '''
@@ -21,8 +21,8 @@ file "LICENSE" for more information.
 #  |    by the Makefile. Manual changes to these values will be lost.      |
 #  ╰────────────────────── Notice ── Notice ── Notice ─────────────────────╯
 
-__version__     = '1.5.4'
-__description__ = 'Apply handwritten text recognition services to document images'
+__version__     = '1.5.6'
+__description__ = 'Run handwritten text recognition services on images of documents'
 __url__         = 'https://github.com/caltechlibrary/handprint'
 __author__      = 'Michael Hucka'
 __email__       = 'mhucka@caltech.edu'
